@@ -34,6 +34,9 @@
 #include "halftone3.h"
 #include "halftone.h"
 
+#include <synfig/localization.h>
+#include <synfig/general.h>
+
 #include <synfig/string.h>
 #include <synfig/time.h>
 #include <synfig/context.h>
@@ -69,7 +72,7 @@ SYNFIG_LAYER_SET_CVS_ID(Halftone3,"$Id$");
 /* === M E T H O D S ======================================================= */
 
 Halftone3::Halftone3():
-Layer_Composite(1.0,Color::BLEND_STRAIGHT)
+Layer_CompositeFork(1.0,Color::BLEND_STRAIGHT)
 {
 	param_size=ValueBase(synfig::Vector(0.25,0.25));
 	param_type=ValueBase(int(TYPE_SYMMETRIC));
@@ -278,14 +281,14 @@ Halftone3::set_param(const String & param, const ValueBase &value)
 
 	IMPORT_VALUE_PLUS(param_subtractive,sync());
 	for(int i=0;i<3;i++)
-		if ((param==strprintf("tone[%d].angle",i) || param==strprintf("tone[%d].angle",i))
+		if (param==strprintf("tone[%d].angle",i)
 			&& tone[i].param_angle.get_type()==value.get_type())
 		{
 			tone[i].param_angle=value;
 			return true;
 		}
 	for(int i=0;i<3;i++)
-		if ((param==strprintf("tone[%d].origin",i) || param==strprintf("tone[%d].origin",i))
+		if ((param==strprintf("tone[%d].origin",i) || param==strprintf("tone[%d].offset",i))
 			&& tone[i].param_origin.get_type()==value.get_type())
 		{
 			tone[i].param_origin=value;
@@ -531,4 +534,8 @@ Halftone3::accelerated_cairorender(Context context, cairo_t *cr, int quality, co
 	return true;
 }
 
+rendering::Task::Handle
+Halftone3::build_rendering_task_vfunc(Context context) const
+	{ return Layer::build_rendering_task_vfunc(context); }
+
 ////
